==> OLIN_1.30.0.zip: OLIN/doc/OLIN.R <==
###################################################
### chunk number 1: 
###################################################
#line 54 "OLIN.Rnw"
  library(OLIN) 


###################################################
### chunk number 2:  eval=FALSE
###################################################
## #line 89 "OLIN.Rnw"
##   data(sw)
##   fgbg.visu(sw[,3])


###################################################
### chunk number 3: 
###################################################
#line 96 "OLIN.Rnw"
  data(sw)
  fgbg.visu(sw[,3])


###################################################
### chunk number 4:  eval=FALSE
###################################################
## #line 113 "OLIN.Rnw"
## plot(maA(sw[,3]),maM(sw[,3]),xlab="A",ylab="M")


###################################################
### chunk number 5: 
###################################################
#line 120 "OLIN.Rnw"
par(cex.lab=0.6)
plot(maA(sw[,3]),maM(sw[,3]),xlab="A",ylab="M",pch='.')


###################################################
### chunk number 6:  eval=FALSE
###################################################
## #line 130 "OLIN.Rnw"
## mxy.plot(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),
##                  Nsc=maNsc(sw),Nsr=maNsr(sw))


###################################################
### chunk number 7: 
###################################################
#line 138 "OLIN.Rnw"
mxy.plot(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),
                 Nsc=maNsc(sw),Nsr=maNsr(sw))


###################################################
### chunk number 8:  eval=FALSE
###################################################
## #line 153 "OLIN.Rnw"
## data(sw.xy)
## mxy.abs.plot(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw))


###################################################
### chunk number 9: 
###################################################
#line 161 "OLIN.Rnw"
data(sw.xy)
mxy.abs.plot(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw))



###################################################
### chunk number 10:  eval=FALSE
###################################################
## #line 180 "OLIN.Rnw"
## data(sw.xy)
## mxy2.plot(maM(sw)[,3],X=sw.xy$X[,3],Y=sw.xy$Y[,3],
##           Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw))
## 


###################################################
### chunk number 11: 
###################################################
#line 190 "OLIN.Rnw"
data(sw.xy)
mxy2.plot(maM(sw)[,3],X=sw.xy$X[,3],sw.xy$Y[,3],
          Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw))



###################################################
### chunk number 12: 
###################################################
#line 303 "OLIN.Rnw"
norm.olin <- olin(sw[,3],X=sw.xy$X[,3],Y=sw.xy$Y[,3])


###################################################
### chunk number 13:  eval=FALSE
###################################################
## #line 315 "OLIN.Rnw"
## plot(maA(norm.olin),maM(norm.olin),main="OLIN",pch=".")
## 
## mxy.plot(maM(norm.olin),Ngc=maNgc(norm.olin),Ngr=maNgr(norm.olin),
##                 Nsc=maNsc(norm.olin),Nsr=maNsr(norm.olin),main="OLIN")
## 


###################################################
### chunk number 14: 
###################################################
#line 328 "OLIN.Rnw"
par(cex.main=0.8)
par(cex.lab =0.8)
plot(maA(norm.olin),maM(norm.olin),main="OLIN",pch=".")


###################################################
### chunk number 15: 
###################################################
#line 342 "OLIN.Rnw"
 
 mxy.plot(maM(norm.olin),Ngc=maNgc(norm.olin),Ngr=maNgr(norm.olin),
                Nsc=maNsc(norm.olin),Nsr=maNsr(norm.olin),main="OLIN")


###################################################
### chunk number 16:  eval=FALSE
###################################################
## #line 357 "OLIN.Rnw"
## norm.olin.1 <- olin(sw[,3],X=sw.xy$X[,3],Y=sw.xy$Y[,3],iter=1)
## norm.olin.2 <- olin(norm.olin.1,X=sw.xy$X[,3],Y=sw.xy$Y[,3],iter=1)
## norm.olin.3 <- olin(norm.olin.2,X=sw.xy$X[,3],Y=sw.xy$Y[,3],iter=1)
## 
## M <- cbind(maM(sw)[,3],maM(norm.olin.1),maM(norm.olin.2),maM(norm.olin.3))
## pairs(M,labels= c("raw","1.Iter.","2.Iter.","3.Iter."))


###################################################
### chunk number 17: 
###################################################
#line 385 "OLIN.Rnw"
norm.oslin <- olin(sw[,3],X=sw.xy$X[,3],Y=sw.xy$Y[,3],alpha=c(0.1,1,0.1),OSLIN=TRUE)


###################################################
### chunk number 18:  eval=FALSE
###################################################
## #line 396 "OLIN.Rnw"
## plot(maA(norm.oslin),maM(norm.oslin),main="OSLIN",pch=".")
## 
## mxy.plot(maM(norm.oslin),Ngc=maNgc(norm.oslin),Ngr=maNgr(norm.oslin),
##                 Nsc=maNsc(norm.oslin),Nsr=maNsr(norm.oslin),main="OSLIN")
## 


###################################################
### chunk number 19: 
###################################################
#line 409 "OLIN.Rnw"
par(cex.main=0.8)
par(cex.lab =0.8)
plot(maA(norm.oslin),maM(norm.oslin),main="OSLIN",pch=".")


###################################################
### chunk number 20: 
###################################################
#line 433 "OLIN.Rnw"
 
 mxy.plot(maM(norm.oslin),Ngc=maNgc(norm.oslin),Ngr=maNgr(norm.oslin),
                Nsc=maNsc(norm.oslin),Nsr=maNsr(norm.oslin),main="OSLIN")


###################################################
### chunk number 21:  eval=FALSE
###################################################
## #line 489 "OLIN.Rnw"
## 
## 
## data(sw.olin)
## 
## # DISTRIBUTION OF LOGGED RATIOS BEFORE BETWEEN-ARRAY-SCALING
## col <- c("red","blue","green","orange")
## M <- maM(sw.olin)
## 
## 
## plot(density(M[,4]),col=col[4],xlim=c(-2,2))
## for (i in 1:3){
##   lines(density(M[,i]),col=col[i])
## }
## 
## 
## # BETWEEN-ARRAY SCALING   
## sw.olin.s <- bas(sw.olin,mode="var")
##   
## 
## # VISUALISATION 
## M <- maM(sw.olin.s)
## plot(density(M[,4]),col=col[4],xlim=c(-2,2))
## for (i in 1:3){
##   lines(density(M[,i]),col=col[i])
## }
## 
## 


###################################################
### chunk number 22: 
###################################################
#line 524 "OLIN.Rnw"
data(sw.olin)
par(cex.main =0.8)
par(cex.lab=0.8)
col <- c("red","blue","green","orange")
M <- maM(sw.olin)
plot(density(M[,4]),col=col[4],xlim=c(-2,2))
for (i in 1:3){
  lines(density(M[,i]),col=col[i])
}


###################################################
### chunk number 23: 
###################################################
#line 542 "OLIN.Rnw"
sw.olin.s <- bas(sw.olin,mode="var")
par(cex.main = 0.8)
par(cex.lab = 0.8)
M <- maM(sw.olin.s)
plot(density(M[,4]),col=col[4],xlim=c(-2,2))
for (i in 1:3){
  lines(density(M[,i]),col=col[i])
}



###################################################
### chunk number 24: 
###################################################
#line 585 "OLIN.Rnw"
 A <- maA(sw[,3])
 M <- maM(sw[,3])
# Averaging
 Mav <- ma.vector(A,M,av="median",delta=50)
# Correlation 
 cor(Mav,M,use="pairwise.complete.obs")


###################################################
### chunk number 25: 
###################################################
#line 596 "OLIN.Rnw"
# From Vector to Matrix
 MM <-  v2m(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw),visu=FALSE)
# Averaging of matrix M 
 MMav <- ma.matrix(MM,av="median",delta= 2,edgeNA=FALSE)
# Backconversion to vector
 Mav <- m2v(MMav,Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw),visu=FALSE)
# Correlation 
 cor(Mav,M,use="pairwise.complete.obs")


###################################################
### chunk number 26: 
###################################################
#line 619 "OLIN.Rnw"
 print(anovaint(sw,index=3,N=10))


###################################################
### chunk number 27: 
###################################################
#line 623 "OLIN.Rnw"
 data(sw.olin)
 print(anovaint(sw.olin,index=3,N=10))


###################################################
### chunk number 28:  eval=FALSE
###################################################
## #line 639 "OLIN.Rnw"
##   anovaspatial(sw,index=3,xN=8,yN=8,visu=TRUE)


###################################################
### chunk number 29:  eval=FALSE
###################################################
## #line 643 "OLIN.Rnw"
##   anovaspatial(sw.olin,index=3,xN=8,yN=8,visu=TRUE) 


###################################################
### chunk number 30: 
###################################################
#line 649 "OLIN.Rnw"
s <-  anovaspatial(sw,index=3,xN=8,yN=8,visu=TRUE)


###################################################
### chunk number 31: 
###################################################
#line 658 "OLIN.Rnw"
s <- anovaspatial(sw.olin,index=3,xN=8,yN=8,visu=TRUE) 


###################################################
### chunk number 32: 
###################################################
#line 676 "OLIN.Rnw"
 print(anovapin(sw.olin,index=3))


###################################################
### chunk number 33: 
###################################################
#line 681 "OLIN.Rnw"
 print(anovaplate(sw.olin,index=3))


###################################################
### chunk number 34:  eval=FALSE
###################################################
## #line 719 "OLIN.Rnw"
## FDR <- fdr.int(maA(sw)[,3],maM(sw)[,3],delta=50,N=10,av="median")
## sigint.plot(maA(sw)[,3],maM(sw)[,3],FDR$FDRp,FDR$FDRn,c(-5,-5))


###################################################
### chunk number 35: 
###################################################
#line 728 "OLIN.Rnw"
FDR <- fdr.int(maA(sw)[,3],maM(sw)[,3],delta=50,N=10,av="median")
sigint.plot(maA(sw)[,3],maM(sw)[,3],FDR$FDRp,FDR$FDRn,c(-5,-5))


###################################################
### chunk number 36:  eval=FALSE
###################################################
## #line 738 "OLIN.Rnw"
## data(sw.olin)
## FDR <- fdr.int(maA(sw.olin)[,3],maM(sw.olin)[,3],delta=50,N=10,av="median")
## sigint.plot(maA(sw.olin)[,3],maM(sw.olin)[,3],FDR$FDRp,FDR$FDRn,c(-5,-5))


###################################################
### chunk number 37: 
###################################################
#line 748 "OLIN.Rnw"
data(sw.olin)
FDR <- fdr.int(maA(sw.olin)[,3],maM(sw.olin)[,3],delta=50,N=10,av="median")
sigint.plot(maA(sw.olin)[,3],maM(sw.olin)[,3],FDR$FDRp,FDR$FDRn,c(-5,-5))


###################################################
### chunk number 38:  eval=FALSE
###################################################
## #line 765 "OLIN.Rnw"
## M <- v2m(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),
##                 Nsc=maNsc(sw),Nsr=maNsr(sw),main="MXY plot of SW-array 1")
## 
## FDR <- fdr.spatial(M,delta=2,N=10,av="median",edgeNA=TRUE)
## sigxy.plot(FDR$FDRp,FDR$FDRn,color.lim=c(-5,5),main="FDR")


###################################################
### chunk number 39: 
###################################################
#line 778 "OLIN.Rnw"
M <- v2m(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),
                Nsc=maNsc(sw),Nsr=maNsr(sw),main="MXY plot of SW-array 1")

FDR <- fdr.spatial(M,delta=2,N=10,av="median",edgeNA=TRUE)
sigxy.plot(FDR$FDRp,FDR$FDRn,color.lim=c(-5,5),main="FDR")


###################################################
### chunk number 40:  eval=FALSE
###################################################
## #line 790 "OLIN.Rnw"
## M<- v2m(maM(sw.olin)[,3],Ngc=maNgc(sw.olin),Ngr=maNgr(sw.olin),
##                 Nsc=maNsc(sw.olin),Nsr=maNsr(sw.olin),main="MXY plot of SW-array 1")
## FDR <- fdr.spatial(M,delta=2,N=10,av="median",edgeNA=TRUE)
## sigxy.plot(FDR$FDRp,FDR$FDRn,color.lim=c(-5,5),main="FDR")


###################################################
### chunk number 41: 
###################################################
#line 800 "OLIN.Rnw"
M<- v2m(maM(sw.olin)[,3],Ngc=maNgc(sw.olin),Ngr=maNgr(sw.olin),
                Nsc=maNsc(sw.olin),Nsr=maNsr(sw.olin),main="MXY plot of SW-array 1")
FDR <- fdr.spatial(M,delta=2,N=10,av="median",edgeNA=TRUE)
sigxy.plot(FDR$FDRp,FDR$FDRn,color.lim=c(-5,5),main="FDR")

==> OLIN_1.34.0.zip: OLIN/doc/OLIN.R <==
### R code from vignette source 'OLIN.Rnw'

###################################################
### code chunk number 1: OLIN.Rnw:53-54
###################################################
  library(OLIN) 


###################################################
### code chunk number 2: OLIN.Rnw:88-90 (eval = FALSE)
###################################################
##   data(sw)
##   fgbg.visu(sw[,3])


###################################################
### code chunk number 3: OLIN.Rnw:95-97
###################################################
  data(sw)
  fgbg.visu(sw[,3])


###################################################
### code chunk number 4: OLIN.Rnw:112-113 (eval = FALSE)
###################################################
## plot(maA(sw[,3]),maM(sw[,3]),xlab="A",ylab="M")


###################################################
### code chunk number 5: OLIN.Rnw:119-121
###################################################
par(cex.lab=0.6)
plot(maA(sw[,3]),maM(sw[,3]),xlab="A",ylab="M",pch='.')


###################################################
### code chunk number 6: OLIN.Rnw:129-131 (eval = FALSE)
###################################################
## mxy.plot(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),
##                  Nsc=maNsc(sw),Nsr=maNsr(sw))


###################################################
### code chunk number 7: OLIN.Rnw:137-139
###################################################
mxy.plot(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),
                 Nsc=maNsc(sw),Nsr=maNsr(sw))


###################################################
### code chunk number 8: OLIN.Rnw:152-154 (eval = FALSE)
###################################################
## data(sw.xy)
## mxy.abs.plot(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw))


###################################################
### code chunk number 9: OLIN.Rnw:160-163
###################################################
data(sw.xy)
mxy.abs.plot(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw))



###################################################
### code chunk number 10: OLIN.Rnw:179-183 (eval = FALSE)
###################################################
## data(sw.xy)
## mxy2.plot(maM(sw)[,3],X=sw.xy$X[,3],Y=sw.xy$Y[,3],
##           Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw))
## 


###################################################
### code chunk number 11: OLIN.Rnw:189-193
###################################################
data(sw.xy)
mxy2.plot(maM(sw)[,3],X=sw.xy$X[,3],sw.xy$Y[,3],
          Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw))



###################################################
### code chunk number 12: OLIN.Rnw:302-303
###################################################
norm.olin <- olin(sw[,3],X=sw.xy$X[,3],Y=sw.xy$Y[,3])


###################################################
### code chunk number 13: OLIN.Rnw:314-319 (eval = FALSE)
###################################################
## plot(maA(norm.olin),maM(norm.olin),main="OLIN",pch=".")
## 
## mxy.plot(maM(norm.olin),Ngc=maNgc(norm.olin),Ngr=maNgr(norm.olin),
##                 Nsc=maNsc(norm.olin),Nsr=maNsr(norm.olin),main="OLIN")
## 


###################################################
### code chunk number 14: OLIN.Rnw:327-330
###################################################
par(cex.main=0.8)
par(cex.lab =0.8)
plot(maA(norm.olin),maM(norm.olin),main="OLIN",pch=".")


###################################################
### code chunk number 15: OLIN.Rnw:341-344
###################################################
 
 mxy.plot(maM(norm.olin),Ngc=maNgc(norm.olin),Ngr=maNgr(norm.olin),
                Nsc=maNsc(norm.olin),Nsr=maNsr(norm.olin),main="OLIN")


###################################################
### code chunk number 16: OLIN.Rnw:356-362 (eval = FALSE)
###################################################
## norm.olin.1 <- olin(sw[,3],X=sw.xy$X[,3],Y=sw.xy$Y[,3],iter=1)
## norm.olin.2 <- olin(norm.olin.1,X=sw.xy$X[,3],Y=sw.xy$Y[,3],iter=1)
## norm.olin.3 <- olin(norm.olin.2,X=sw.xy$X[,3],Y=sw.xy$Y[,3],iter=1)
## 
## M <- cbind(maM(sw)[,3],maM(norm.olin.1),maM(norm.olin.2),maM(norm.olin.3))
## pairs(M,labels= c("raw","1.Iter.","2.Iter.","3.Iter."))


###################################################
### code chunk number 17: OLIN.Rnw:384-385
###################################################
norm.oslin <- olin(sw[,3],X=sw.xy$X[,3],Y=sw.xy$Y[,3],alpha=c(0.1,1,0.1),OSLIN=TRUE)


###################################################
### code chunk number 18: OLIN.Rnw:395-400 (eval = FALSE)
###################################################
## plot(maA(norm.oslin),maM(norm.oslin),main="OSLIN",pch=".")
## 
## mxy.plot(maM(norm.oslin),Ngc=maNgc(norm.oslin),Ngr=maNgr(norm.oslin),
##                 Nsc=maNsc(norm.oslin),Nsr=maNsr(norm.oslin),main="OSLIN")
## 


###################################################
### code chunk number 19: OLIN.Rnw:408-411
###################################################
par(cex.main=0.8)
par(cex.lab =0.8)
plot(maA(norm.oslin),maM(norm.oslin),main="OSLIN",pch=".")


###################################################
### code chunk number 20: OLIN.Rnw:432-435
###################################################
 
 mxy.plot(maM(norm.oslin),Ngc=maNgc(norm.oslin),Ngr=maNgr(norm.oslin),
                Nsc=maNsc(norm.oslin),Nsr=maNsr(norm.oslin),main="OSLIN")


###################################################
### code chunk number 21: OLIN.Rnw:488-515 (eval = FALSE)
###################################################
## 
## 
## data(sw.olin)
## 
## # DISTRIBUTION OF LOGGED RATIOS BEFORE BETWEEN-ARRAY-SCALING
## col <- c("red","blue","green","orange")
## M <- maM(sw.olin)
## 
## 
## plot(density(M[,4]),col=col[4],xlim=c(-2,2))
## for (i in 1:3){
##   lines(density(M[,i]),col=col[i])
## }
## 
## 
## # BETWEEN-ARRAY SCALING   
## sw.olin.s <- bas(sw.olin,mode="var")
##   
## 
## # VISUALISATION 
## M <- maM(sw.olin.s)
## plot(density(M[,4]),col=col[4],xlim=c(-2,2))
## for (i in 1:3){
##   lines(density(M[,i]),col=col[i])
## }
## 
## 


###################################################
### code chunk number 22: OLIN.Rnw:523-532
###################################################
data(sw.olin)
par(cex.main =0.8)
par(cex.lab=0.8)
col <- c("red","blue","green","orange")
M <- maM(sw.olin)
plot(density(M[,4]),col=col[4],xlim=c(-2,2))
for (i in 1:3){
  lines(density(M[,i]),col=col[i])
}


###################################################
### code chunk number 23: OLIN.Rnw:541-550
###################################################
sw.olin.s <- bas(sw.olin,mode="var")
par(cex.main = 0.8)
par(cex.lab = 0.8)
M <- maM(sw.olin.s)
plot(density(M[,4]),col=col[4],xlim=c(-2,2))
for (i in 1:3){
  lines(density(M[,i]),col=col[i])
}



###################################################
### code chunk number 24: OLIN.Rnw:584-590
###################################################
 A <- maA(sw[,3])
 M <- maM(sw[,3])
# Averaging
 Mav <- ma.vector(A,M,av="median",delta=50)
# Correlation 
 cor(Mav,M,use="pairwise.complete.obs")


###################################################
### code chunk number 25: OLIN.Rnw:595-603
###################################################
# From Vector to Matrix
 MM <-  v2m(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw),visu=FALSE)
# Averaging of matrix M 
 MMav <- ma.matrix(MM,av="median",delta= 2,edgeNA=FALSE)
# Backconversion to vector
 Mav <- m2v(MMav,Ngc=maNgc(sw),Ngr=maNgr(sw),Nsc=maNsc(sw),Nsr=maNsr(sw),visu=FALSE)
# Correlation 
 cor(Mav,M,use="pairwise.complete.obs")


###################################################
### code chunk number 26: OLIN.Rnw:618-619
###################################################
 print(anovaint(sw,index=3,N=10))


###################################################
### code chunk number 27: OLIN.Rnw:622-624
###################################################
 data(sw.olin)
 print(anovaint(sw.olin,index=3,N=10))


###################################################
### code chunk number 28: OLIN.Rnw:638-639 (eval = FALSE)
###################################################
##   anovaspatial(sw,index=3,xN=8,yN=8,visu=TRUE)


###################################################
### code chunk number 29: OLIN.Rnw:642-643 (eval = FALSE)
###################################################
##   anovaspatial(sw.olin,index=3,xN=8,yN=8,visu=TRUE) 


###################################################
### code chunk number 30: OLIN.Rnw:648-649
###################################################
s <-  anovaspatial(sw,index=3,xN=8,yN=8,visu=TRUE)


###################################################
### code chunk number 31: OLIN.Rnw:657-658
###################################################
s <- anovaspatial(sw.olin,index=3,xN=8,yN=8,visu=TRUE) 


###################################################
### code chunk number 32: OLIN.Rnw:675-676
###################################################
 print(anovapin(sw.olin,index=3))


###################################################
### code chunk number 33: OLIN.Rnw:680-681
###################################################
 print(anovaplate(sw.olin,index=3))


###################################################
### code chunk number 34: OLIN.Rnw:718-720 (eval = FALSE)
###################################################
## FDR <- fdr.int(maA(sw)[,3],maM(sw)[,3],delta=50,N=10,av="median")
## sigint.plot(maA(sw)[,3],maM(sw)[,3],FDR$FDRp,FDR$FDRn,c(-5,-5))


###################################################
### code chunk number 35: OLIN.Rnw:727-729
###################################################
FDR <- fdr.int(maA(sw)[,3],maM(sw)[,3],delta=50,N=10,av="median")
sigint.plot(maA(sw)[,3],maM(sw)[,3],FDR$FDRp,FDR$FDRn,c(-5,-5))


###################################################
### code chunk number 36: OLIN.Rnw:737-740 (eval = FALSE)
###################################################
## data(sw.olin)
## FDR <- fdr.int(maA(sw.olin)[,3],maM(sw.olin)[,3],delta=50,N=10,av="median")
## sigint.plot(maA(sw.olin)[,3],maM(sw.olin)[,3],FDR$FDRp,FDR$FDRn,c(-5,-5))


###################################################
### code chunk number 37: OLIN.Rnw:747-750
###################################################
data(sw.olin)
FDR <- fdr.int(maA(sw.olin)[,3],maM(sw.olin)[,3],delta=50,N=10,av="median")
sigint.plot(maA(sw.olin)[,3],maM(sw.olin)[,3],FDR$FDRp,FDR$FDRn,c(-5,-5))


###################################################
### code chunk number 38: OLIN.Rnw:764-769 (eval = FALSE)
###################################################
## M <- v2m(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),
##                 Nsc=maNsc(sw),Nsr=maNsr(sw),main="MXY plot of SW-array 1")
## 
## FDR <- fdr.spatial(M,delta=2,N=10,av="median",edgeNA=TRUE)
## sigxy.plot(FDR$FDRp,FDR$FDRn,color.lim=c(-5,5),main="FDR")


###################################################
### code chunk number 39: OLIN.Rnw:777-782
###################################################
M <- v2m(maM(sw)[,3],Ngc=maNgc(sw),Ngr=maNgr(sw),
                Nsc=maNsc(sw),Nsr=maNsr(sw),main="MXY plot of SW-array 1")

FDR <- fdr.spatial(M,delta=2,N=10,av="median",edgeNA=TRUE)
sigxy.plot(FDR$FDRp,FDR$FDRn,color.lim=c(-5,5),main="FDR")


###################################################
### code chunk number 40: OLIN.Rnw:789-793 (eval = FALSE)
###################################################
## M<- v2m(maM(sw.olin)[,3],Ngc=maNgc(sw.olin),Ngr=maNgr(sw.olin),
##                 Nsc=maNsc(sw.olin),Nsr=maNsr(sw.olin),main="MXY plot of SW-array 1")
## FDR <- fdr.spatial(M,delta=2,N=10,av="median",edgeNA=TRUE)
## sigxy.plot(FDR$FDRp,FDR$FDRn,color.lim=c(-5,5),main="FDR")


###################################################
### code chunk number 41: OLIN.Rnw:799-803
###################################################
M<- v2m(maM(sw.olin)[,3],Ngc=maNgc(sw.olin),Ngr=maNgr(sw.olin),
                Nsc=maNsc(sw.olin),Nsr=maNsr(sw.olin),main="MXY plot of SW-array 1")
FDR <- fdr.spatial(M,delta=2,N=10,av="median",edgeNA=TRUE)
sigxy.plot(FDR$FDRp,FDR$FDRn,color.lim=c(-5,5),main="FDR")
